==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/svp/lang/svp_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'action_patienter' => 'O seveniñ an oberezhioù emeur. Gortozit mar plij...',
	'actions_a_faire' => 'Obererezhioù da dretañ',
	'actions_demandees' => 'Obererezhioù goulennet :',
	'actions_en_erreur' => 'Fazioù c’hoarvezet',
	'actions_necessaires' => 'An obererezhioù ouzhpenn mañ a vo sevenet :',
	'actions_non_traitees' => 'Oberezhioù ket bet sevenet',
	'actions_realises' => 'Oberezhioù sevenet',
	'afficher_les_plugins_incompatibles' => 'Diskwel ar pluginoù  diembreget',
	'alerte_compatibilite' => ' Kenglotusted forset',
	'alerte_compatibilite_version_autorisee' => 'Ar plugins kenglotus gant SPIP <code>@version@</code> a dle bezañ gweredekaet.',

	// B
	'bouton_activer' => 'Gweredekaat',
	'bouton_actualiser' => 'Hizivaat',
	'bouton_actualiser_tout' => 'Hizivaat an daspugnadoù',
	'bouton_appliquer' => 'Arloañ',
	'bouton_confirmer' => 'Kadarnaat',
	'bouton_desactiver' => 'Diweredekaat',
	'bouton_desinstaller' => 'Distaliañ',
	'bouton_installer' => 'Pellgargañ ha gweredekaat',
	'bouton_modifier_depot' => 'Daskemmañ an daspugnad',
	'bouton_supprimer' => 'Dilemel',
	'bouton_up' => 'Hizivaat',
	'bulle_actualiser_depot' => 'Hizivaat pakadoù an daspugnad',
	'bulle_actualiser_tout_depot' => 'Hizivaat pakadoù an holl daspugnadoù',
	'bulle_afficher_xml_plugin' => 'Endalc’had restr XML ar plugin',
	'bulle_ajouter_spipzone' => 'Ouzhpennañ an daspugnad SPIP-Zone',
	'bulle_aller_demonstration' => 'Mont d’ar bajenn an diskouezadur',
	'bulle_aller_depot' => 'Mont war bajenn an daspugnad-mañ',
	'bulle_aller_documentation' => 'Mont war bajenn an teuliaouiñ',
	'bulle_aller_plugin' => 'Mont war bajenn ar plugin',
	'bulle_supprimer_depot' => 'Dilemel an daspugnad hag e bakadoù',
	'bulle_telecharger_archive' => 'Pellgargañ an diell',
	'bulle_telecharger_fichier_depot' => 'Pellgargañ restr XML an daspugnad',
	'bulle_telecharger_librairie' => 'Pellgaragañ al levraoueg',

	// C
	'cacher_les_plugins_incompatibles' => 'Kuzhat ar pluginoù diembreget',
	'config_activer_log_verbeux' => 'Ober gant al logoù ragell ?',
	'config_activer_log_verbeux_explication' => 'An dibab-mañ a laka logoù SVP kalz ragelloc’h...',
	'config_activer_pas_a_pas' => 'Gweredekaat ar mod paz ouzh paz',
	'config_activer_pas_a_pas_explication' => 'En ur weredekaat ar mod-se e c’halloc’h diskwel ur bilañs war-lerc’h pep obererezh echu, e lec’h kaout nemet ur bilañs hollek eus an holl traoù a zo bet kaset da benn.',
	'config_activer_runtime' => 'Gweredekaat ar mod runtime ?',
	'config_autoriser_activer_paquets_obsoletes' => 'Aotren gweredekadur ar pakadoù diamzeret ?',
	'config_depot_editable' => 'Permetiñ embannadur an daspugnadoù ?',
	'confirmer_desinstaller' => 'Diwallit, distaliañ ur plugin <b>a ziverk</b> e roadennoù deus an diaz ha ne vez ket bet cheñchet.<br />Ma n’oc’h ket sur, diwerekait hepken ar plugin.',

	// E
	'erreur_auth_plugins_ajouter_lib' => 'N’hoc’h eus ket ar gwirioù  evit ouzhpennañ ul levraoueg.',
	'erreur_dir_dib_indefini' => 'n’eo ket termenet ar c’havlec’h _DIR_LIB. Ne c’haller ket kagañ warnan ul levraoueg !',
	'erreurs_xml' => 'Ne c’haller ket lenn ur pennad deskrivadur XML',

	// F
	'fieldset_edition' => 'Embannadur',
	'filtrer' => 'Silañ',

	// I
	'info_0_plugin' => 'Plugin ebet',
	'info_1_depot' => '1 daspugnad',
	'info_1_paquet' => '1 pakad',
	'info_1_plugin' => '1 plugin',
	'info_adresse_spipzone' => 'SPIP-Zone - Plugins',
	'info_aucun_depot' => 'daspugnad ebet',
	'info_aucun_paquet' => 'pakad ebet',
	'info_aucun_plugin' => 'plugin ebet',
	'info_compatibilite_dependance' => 'Evit @compatibilite@ :',
	'info_depots_disponibles' => '@total_depots@ daspugnadoù',
	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ ha @signe_max@ @version_max@',
	'info_nb_depots' => '@nb@ daspugnadoù',
	'info_nb_paquets' => '@nb@ pakadoù',
	'info_nb_plugins' => '@nb@ plugins',
	'info_plugin_incompatible' => 'stumm digenglotus',
	'info_plugin_obsolete' => 'stumm marv',
	'info_type_depot_git' => 'Daspugnad meret dindan GIT',
	'info_type_depot_svn' => 'Dasougnad meret dindan SVN',

	// L
	'label_actualise_le' => 'Freskaet d’an',
	'label_critere_depot' => 'Daspugnadoù',
	'label_critere_etat' => 'Statudoù',
	'label_critere_phrase' => 'Klask er plugins',
	'label_modifie_le' => 'Cheñchet d’an',
	'label_prefixe' => 'Rakger',
	'label_selectionner_plugin' => 'Dibab ar plugin-mañ',
	'label_tags' => 'Tags',
	'label_type_depot' => 'Doare daspugnad :',
	'label_type_depot_git' => 'Daspugnad dindan GIT',
	'label_type_depot_manuel' => 'Daspugnad dre zorn',
	'label_type_depot_svn' => 'Daspugnad dindan SVN',
	'label_url_serveur' => 'URL ar servijer',
	'label_version' => 'Stumm',
	'label_xml_depot' => 'Restr XML an daspugnad',
	'label_xml_plugin' => 'XML',
	'legende_installer_plugins' => 'Staliañ plugins',
	'legende_rechercher_plugins' => 'Klask plugins',
	'lien_demo' => 'Diskouez',
	'lien_documentation' => 'Teuliadur',

	// M
	'message_action_finale_getlib_fail' => 'Staliañ al levraoueg « @plugin@ » a zo sac’het',
	'message_action_finale_install_fail' => 'Staliañ ar plugin « @plugin@ » (version : @version@) a zo sac’het',
	'message_action_get' => 'Pellgargañ ar plugin « @plugin@ » (version : @version@)',
	'message_action_getlib' => 'Pellgargañ al levraoueg « <a href="@version@" class="spip_out">@plugin@</a> »',
	'message_action_geton' => 'Pellgargañ ha gweredekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_kill' => 'Dilemel restroù ar plugin « @plugin@ » (version : @version@)',
	'message_action_off' => 'Diwerekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_on' => 'Gweredekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_stop' => 'Distaliañ ar plugin « @plugin@ » (version : @version@)',
	'message_erreur_aucun_plugin_selectionne' => 'Plugin dibabet ebet.',
	'message_erreur_maj_inconnu' => 'Dibosubl eo hizivaat ur plugin dianav.',
	'message_erreur_plugin_introuvable' => 'Dibosubl eo kavout ar plugin @plugin@ evit @action@.',
	'message_erreur_plugin_non_actif' => 'Dibosubl eo diwerekaat ur plugin anoberiek.',
	'message_nok_aucun_plugin_selectionne' => 'N’eus plugin o staliañ ebet. Dibabit ar plugins o staliañ',
	'message_nok_url_depot_incorrecte' => 'N’eo ket mat chomlec’h « @url@ » ',

	// O
	'onglet_depots' => 'Merañ an daspugnadoù',
	'option_depot_tout' => 'A bep daspugnadoù',
	'option_doublon_non' => 'Ar stumm nevesañ',
	'option_doublon_oui' => 'An holl stummoù kenglotus',
	'option_etat_tout' => 'Pep statudoù',

	// P
	'plugin_info_actif' => 'Plugin efedus',
	'plugin_info_verrouille' => 'Plugin prennet',
	'plugins_inactifs_liste' => 'Marv',
	'plugins_non_verrouilles_liste' => 'Digor',
	'plugins_verrouilles_liste' => 'Prennet',

	// R
	'resume_table_paquets' => 'Roll ar pakadoù',
	'resume_table_plugins' => 'Roll ar plugins @categorie@',

	// T
	'titre_depot' => 'Daspugnad',
	'titre_depots' => 'Daspugnadoù',
	'titre_form_ajouter_depot' => 'Ouzhpennañ un daspugnad',
	'titre_form_charger_plugin' => 'Klask hag ouzhpennañ plugins',
	'titre_liste_autres_depots' => 'Daspugnadoù all',
	'titre_liste_paquets_plugin' => 'Roll pakadoù ar plugin',
	'titre_liste_plugins' => 'Roll ar plugins',
	'titre_logo_depot' => 'Logo an daspugnad',
	'titre_logo_plugin' => 'Logo ar plugin',
	'titre_nouveau_depot' => 'Daspugnad nevez',
	'titre_page_configurer' => 'Servijer Plugins',
	'titre_paquet' => 'Pakad',
	'titre_paquets' => 'Pakadoù',
	'titre_plugin' => 'Plugin',
	'titre_plugins' => 'Plugins',
	'tout_cocher' => 'Gevaskañ pep unan',
	'tout_cocher_up' => 'Gevaskañ an hizivaat',
	'tout_decocher' => 'Disgevaskañ pep unan'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/svp/lang/svp_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'action_patienter' => 'O seveniñ an oberezhioù emeur. Gortozit mar plij...',
	'actions_a_faire' => 'Obererezhioù da dretañ',
	'actions_demandees' => 'Obererezhioù goulennet :',
	'actions_en_erreur' => 'Fazioù c’hoarvezet',
	'actions_necessaires' => 'An obererezhioù ouzhpenn mañ a vo sevenet :',
	'actions_non_traitees' => 'Oberezhioù ket bet sevenet',
	'actions_realises' => 'Oberezhioù sevenet',
	'afficher_les_plugins_incompatibles' => 'Diskwel ar pluginoù  diembreget',
	'alerte_compatibilite' => ' Kenglotusted forset',
	'alerte_compatibilite_version_autorisee' => 'Ar plugins kenglotus gant SPIP <code>@version@</code> a dle bezañ gweredekaet.',

	// B
	'bouton_activer' => 'Gweredekaat',
	'bouton_actualiser' => 'Hizivaat',
	'bouton_actualiser_tout' => 'Hizivaat an daspugnadoù',
	'bouton_appliquer' => 'Arloañ',
	'bouton_confirmer' => 'Kadarnaat',
	'bouton_desactiver' => 'Diweredekaat',
	'bouton_desinstaller' => 'Distaliañ',
	'bouton_installer' => 'Pellgargañ ha gweredekaat',
	'bouton_modifier_depot' => 'Daskemmañ an daspugnad',
	'bouton_supprimer' => 'Dilemel',
	'bouton_up' => 'Hizivaat',
	'bulle_actualiser_depot' => 'Hizivaat pakadoù an daspugnad',
	'bulle_actualiser_tout_depot' => 'Hizivaat pakadoù an holl daspugnadoù',
	'bulle_afficher_xml_plugin' => 'Endalc’had restr XML ar plugin',
	'bulle_ajouter_spipzone' => 'Ouzhpennañ an daspugnad SPIP-Zone',
	'bulle_aller_demonstration' => 'Mont d’ar bajenn an diskouezadur',
	'bulle_aller_depot' => 'Mont war bajenn an daspugnad-mañ',
	'bulle_aller_documentation' => 'Mont war bajenn an teuliaouiñ',
	'bulle_aller_plugin' => 'Mont war bajenn ar plugin',
	'bulle_supprimer_depot' => 'Dilemel an daspugnad hag e bakadoù',
	'bulle_telecharger_archive' => 'Pellgargañ an diell',
	'bulle_telecharger_fichier_depot' => 'Pellgargañ restr XML an daspugnad',
	'bulle_telecharger_librairie' => 'Pellgaragañ al levraoueg',

	// C
	'cacher_les_plugins_incompatibles' => 'Kuzhat ar pluginoù diembreget',
	'config_activer_log_verbeux' => 'Ober gant al logoù ragell ?',
	'config_activer_log_verbeux_explication' => 'An dibab-mañ a laka logoù SVP kalz ragelloc’h...',
	'config_activer_pas_a_pas' => 'Gweredekaat ar mod paz ouzh paz',
	'config_activer_pas_a_pas_explication' => 'En ur weredekaat ar mod-se e c’halloc’h diskwel ur bilañs war-lerc’h pep obererezh echu, e lec’h kaout nemet ur bilañs hollek eus an holl traoù a zo bet kaset da benn.',
	'config_activer_runtime' => 'Gweredekaat ar mod runtime ?',
	'config_autoriser_activer_paquets_obsoletes' => 'Aotren gweredekadur ar pakadoù diamzeret ?',
	'config_depot_editable' => 'Permetiñ embannadur an daspugnadoù ?',
	'confirmer_desinstaller' => 'Diwallit, distaliañ ur plugin <b>a ziverk</b> e roadennoù deus an diaz ha ne vez ket bet cheñchet.<br />Ma n’oc’h ket sur, diwerekait hepken ar plugin.',

	// E
	'erreur_auth_plugins_ajouter_lib' => 'N’hoc’h eus ket ar gwirioù  evit ouzhpennañ ul levraoueg.',
	'erreur_dir_dib_indefini' => 'n’eo ket termenet ar c’havlec’h _DIR_LIB. Ne c’haller ket kagañ warnan ul levraoueg !',
	'erreurs_xml' => 'Ne c’haller ket lenn ur pennad deskrivadur XML',

	// F
	'fieldset_edition' => 'Embannadur',
	'filtrer' => 'Silañ',

	// I
	'info_0_plugin' => 'Plugin ebet',
	'info_1_depot' => '1 daspugnad',
	'info_1_paquet' => '1 pakad',
	'info_1_plugin' => '1 plugin',
	'info_adresse_spipzone' => 'SPIP-Zone - Plugins',
	'info_aucun_depot' => 'daspugnad ebet',
	'info_aucun_paquet' => 'pakad ebet',
	'info_aucun_plugin' => 'plugin ebet',
	'info_compatibilite_dependance' => 'Evit @compatibilite@ :',
	'info_depots_disponibles' => '@total_depots@ daspugnadoù',
	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ ha @signe_max@ @version_max@',
	'info_nb_depots' => '@nb@ daspugnadoù',
	'info_nb_paquets' => '@nb@ pakadoù',
	'info_nb_plugins' => '@nb@ plugins',
	'info_plugin_incompatible' => 'stumm digenglotus',
	'info_plugin_obsolete' => 'stumm marv',
	'info_type_depot_git' => 'Daspugnad meret dindan GIT',
	'info_type_depot_svn' => 'Dasougnad meret dindan SVN',

	// L
	'label_actualise_le' => 'Freskaet d’an',
	'label_critere_depot' => 'Daspugnadoù',
	'label_critere_etat' => 'Statudoù',
	'label_critere_phrase' => 'Klask er plugins',
	'label_modifie_le' => 'Cheñchet d’an',
	'label_prefixe' => 'Rakger',
	'label_selectionner_plugin' => 'Dibab ar plugin-mañ',
	'label_tags' => 'Tags',
	'label_type_depot' => 'Doare daspugnad :',
	'label_type_depot_git' => 'Daspugnad dindan GIT',
	'label_type_depot_manuel' => 'Daspugnad dre zorn',
	'label_type_depot_svn' => 'Daspugnad dindan SVN',
	'label_url_serveur' => 'URL ar servijer',
	'label_version' => 'Stumm',
	'label_xml_depot' => 'Restr XML an daspugnad',
	'label_xml_plugin' => 'XML',
	'legende_installer_plugins' => 'Staliañ plugins',
	'legende_rechercher_plugins' => 'Klask plugins',
	'lien_demo' => 'Diskouez',
	'lien_documentation' => 'Teuliadur',

	// M
	'message_action_finale_getlib_fail' => 'Staliañ al levraoueg « @plugin@ » a zo sac’het',
	'message_action_finale_install_fail' => 'Staliañ ar plugin « @plugin@ » (version : @version@) a zo sac’het',
	'message_action_get' => 'Pellgargañ ar plugin « @plugin@ » (version : @version@)',
	'message_action_getlib' => 'Pellgargañ al levraoueg « <a href="@version@" class="spip_out">@plugin@</a> »',
	'message_action_geton' => 'Pellgargañ ha gweredekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_kill' => 'Dilemel restroù ar plugin « @plugin@ » (version : @version@)',
	'message_action_off' => 'Diwerekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_on' => 'Gweredekaat ar plugin « @plugin@ » (version : @version@)',
	'message_action_stop' => 'Distaliañ ar plugin « @plugin@ » (version : @version@)',
	'message_erreur_aucun_plugin_selectionne' => 'Plugin dibabet ebet.',
	'message_erreur_maj_inconnu' => 'Dibosubl eo hizivaat ur plugin dianav.',
	'message_erreur_plugin_introuvable' => 'Dibosubl eo kavout ar plugin @plugin@ evit @action@.',
	'message_erreur_plugin_non_actif' => 'Dibosubl eo diwerekaat ur plugin anoberiek.',
	'message_nok_aucun_plugin_selectionne' => 'N’eus plugin o staliañ ebet. Dibabit ar plugins o staliañ',
	'message_nok_url_depot_incorrecte' => 'N’eo ket mat chomlec’h « @url@ » ',

	// O
	'onglet_depots' => 'Merañ an daspugnadoù',
	'option_depot_tout' => 'A bep daspugnadoù',
	'option_doublon_non' => 'Ar stumm nevesañ',
	'option_doublon_oui' => 'An holl stummoù kenglotus',
	'option_etat_tout' => 'Pep statudoù',

	// P
	'plugin_info_actif' => 'Plugin efedus',
	'plugin_info_verrouille' => 'Plugin prennet',
	'plugins_inactifs_liste' => 'Marv',
	'plugins_non_verrouilles_liste' => 'Digor',
	'plugins_verrouilles_liste' => 'Prennet',

	// R
	'resume_table_paquets' => 'Roll ar pakadoù',
	'resume_table_plugins' => 'Roll ar plugins @categorie@',

	// T
	'titre_depot' => 'Daspugnad',
	'titre_depots' => 'Daspugnadoù',
	'titre_form_ajouter_depot' => 'Ouzhpennañ un daspugnad',
	'titre_form_charger_plugin' => 'Klask hag ouzhpennañ plugins',
	'titre_liste_autres_depots' => 'Daspugnadoù all',
	'titre_liste_paquets_plugin' => 'Roll pakadoù ar plugin',
	'titre_liste_plugins' => 'Roll ar plugins',
	'titre_logo_depot' => 'Logo an daspugnad',
	'titre_logo_plugin' => 'Logo ar plugin',
	'titre_nouveau_depot' => 'Daspugnad nevez',
	'titre_page_configurer' => 'Servijer Plugins',
	'titre_paquet' => 'Pakad',
	'titre_paquets' => 'Pakadoù',
	'titre_plugin' => 'Plugin',
	'titre_plugins' => 'Plugins',
	'tout_cocher' => 'Gevaskañ pep unan',
	'tout_cocher_up' => 'Gevaskañ an hizivaat',
	'tout_decocher' => 'Disgevaskañ pep unan',
];
